@@ -1,3 +1,4 @@
+# TODO: Need to make it singleton, one class per service
 class Constants:
 
     def __init__(self):
@@ -12,3 +13,6 @@ class Constants:
 
     def get_value_by_key(self, key):
         self.__parameter_map.get(key, None)
+
+
+CONSTANTS_INSTANCE = Constants()
